@@ -14,7 +14,7 @@ __license__  = "GNU GPL version 3 or any later version"
 
 # Modified by Marie E. Rognes, 2010
 
-# Last changed: 2010-06-21
+# Last changed: 2011-01-13
 
 # UFL modules
 from ufl.common import istr, tstr
@@ -106,6 +106,10 @@ def _get_nested_elements(element):
 def _analyze_form(form, object_names, parameters, common_cell=None):
     "Analyze form, returning preprocessed form."
 
+    # Check that form is not empty
+    ffc_assert(len(form.integrals()),
+               "Form (%s) seems to be zero: cannot compile it." % str(form))
+
     # Preprocess form if necessary
     if form.form_data() is None:
         form = preprocess(form, object_names, common_cell)
@@ -143,6 +147,9 @@ def _adjust_elements(form_data):
     if common_degree is None:
         common_degree = default_quadrature_degree
 
+    # Degree must be at least 1 (to work with Lagrange elements)
+    common_degree = max(1, common_degree)
+
     # Set cell and degree if missing
     for element in form_data.sub_elements:
 
