@@ -12,7 +12,7 @@ __copyright__ = "Copyright (C) 2009 " + __author__
 __license__  = "GNU GPL version 3 or any later version"
 
 # Modified by Mehdi Nikbakht, 2010
-# Last changed: 2010-06-15
+# Last changed: 2011-02-21
 
 # FFC modules
 from ffc.log import info, begin, end, debug_code
@@ -30,8 +30,9 @@ from ffc.interpolatevertexvalues import interpolate_vertex_values
 from ffc import quadrature
 from ffc import tensor
 
-# FIXME: Temporary
-not_implemented = "// Not implemented, please fix me!"
+# Errors issued for non-implemented functions
+map_from_reference_cell = "map_from_reference_cell not yet implemented (introduced in UFC 2.0)."
+map_to_reference_cell = "map_to_reference_cell not yet implemented (introduced in UFC 2.0)."
 
 def generate_code(ir, prefix, parameters):
     "Generate code from intermediate representation."
@@ -75,9 +76,11 @@ def _generate_element_code(ir, prefix, parameters):
     if ir is None: return None
 
     # Prefetch formatting to speedup code generation
-    ret =         format["return"]
-    classname =   format["classname finite_element"]
-    do_nothing =  format["do nothing"]
+    ret        = format["return"]
+    classname  = format["classname finite_element"]
+    do_nothing = format["do nothing"]
+    create     = format["create foo"]
+    exception  = format["exception"]
 
     # Codes generated together
     (evaluate_dof_code, evaluate_dofs_code) = evaluate_dof_and_dofs(ir["evaluate_dof"])
@@ -92,6 +95,8 @@ def _generate_element_code(ir, prefix, parameters):
     code["destructor"] = do_nothing
     code["signature"] = ret('"%s"' % ir["signature"])
     code["cell_shape"] = ret(format["cell"](ir["cell_shape"]))
+    code["topological_dimension"] = ret(ir["topological_dimension"])
+    code["geometric_dimension"] = ret(ir["geometric_dimension"])
     code["space_dimension"] = ret(ir["space_dimension"])
     code["value_rank"] = ret(ir["value_rank"])
     code["value_dimension"] = _value_dimension(ir["value_dimension"])
@@ -102,8 +107,11 @@ def _generate_element_code(ir, prefix, parameters):
     code["evaluate_dof"] = evaluate_dof_code
     code["evaluate_dofs"] = evaluate_dofs_code
     code["interpolate_vertex_values"] = interpolate_vertex_values(ir["interpolate_vertex_values"])
+    code["map_from_reference_cell"] = exception(map_from_reference_cell)
+    code["map_to_reference_cell"] = exception(map_to_reference_cell)
     code["num_sub_elements"] = ret(ir["num_sub_elements"])
     code["create_sub_element"] = _create_foo(prefix, "finite_element", ir["create_sub_element"])
+    code["create"] = ret(create(code["classname"]))
 
     # Postprocess code
     _postprocess_code(code, parameters)
@@ -117,14 +125,15 @@ def _generate_dofmap_code(ir, prefix, parameters):
     if ir is None: return None
 
     # Prefetch formatting to speedup code generation
-    ret =         format["return"]
-    classname =   format["classname dof_map"]
-    declare =     format["declaration"]
-    assign =      format["assign"]
-    do_nothing =  format["do nothing"]
-    switch =      format["switch"]
-    f_int =       format["int"]
-    f_d =         format["argument dimension"]
+    ret        = format["return"]
+    classname  = format["classname dofmap"]
+    declare    = format["declaration"]
+    assign     = format["assign"]
+    do_nothing = format["do nothing"]
+    switch     = format["switch"]
+    f_int      = format["int"]
+    f_d        = format["argument dimension"]
+    create     = format["create foo"]
 
     # Generate code
     code = {}
@@ -139,18 +148,20 @@ def _generate_dofmap_code(ir, prefix, parameters):
     code["init_mesh"] = _init_mesh(ir["init_mesh"])
     code["init_cell"] = do_nothing
     code["init_cell_finalize"] = do_nothing
+    code["topological_dimension"] = ret(ir["topological_dimension"])
+    code["geometric_dimension"] = ret(ir["geometric_dimension"])
     code["global_dimension"] = ret("_global_dimension")
     code["local_dimension"] = ret(ir["local_dimension"])
     code["max_local_dimension"] = ret(ir["max_local_dimension"])
-    code["geometric_dimension"] = ret(ir["geometric_dimension"])
     code["num_facet_dofs"] = ret(ir["num_facet_dofs"])
     code["num_entity_dofs"] = switch(f_d, [ret(num) for num in ir["num_entity_dofs"]], ret(f_int(0)))
     code["tabulate_dofs"] = _tabulate_dofs(ir["tabulate_dofs"])
     code["tabulate_facet_dofs"] = _tabulate_facet_dofs(ir["tabulate_facet_dofs"])
     code["tabulate_entity_dofs"] = _tabulate_entity_dofs(ir["tabulate_entity_dofs"])
     code["tabulate_coordinates"] = _tabulate_coordinates(ir["tabulate_coordinates"])
-    code["num_sub_dof_maps"] = ret(ir["num_sub_dof_maps"])
-    code["create_sub_dof_map"] = _create_foo(prefix, "dof_map", ir["create_sub_dof_map"])
+    code["num_sub_dofmaps"] = ret(ir["num_sub_dofmaps"])
+    code["create_sub_dofmap"] = _create_foo(prefix, "dofmap", ir["create_sub_dofmap"])
+    code["create"] = ret(create(code["classname"]))
 
     # Postprocess code
     _postprocess_code(code, parameters)
@@ -201,11 +212,11 @@ def _generate_form_code(ir, prefix, parameters):
     code["signature"] = ret('"%s"' % ir["signature"])
     code["rank"] = ret(ir["rank"])
     code["num_coefficients"] = ret(ir["num_coefficients"])
-    code["num_cell_integrals"] = ret(ir["num_cell_integrals"])
-    code["num_exterior_facet_integrals"] = ret(ir["num_exterior_facet_integrals"])
-    code["num_interior_facet_integrals"] = ret(ir["num_interior_facet_integrals"])
+    code["num_cell_domains"] = ret(ir["num_cell_domains"])
+    code["num_exterior_facet_domains"] = ret(ir["num_exterior_facet_domains"])
+    code["num_interior_facet_domains"] = ret(ir["num_interior_facet_domains"])
     code["create_finite_element"] = _create_foo(prefix, "finite_element", ir["create_finite_element"])
-    code["create_dof_map"] = _create_foo(prefix, "dof_map", ir["create_dof_map"])
+    code["create_dofmap"] = _create_foo(prefix, "dofmap", ir["create_dofmap"])
     code["create_cell_integral"] = _create_foo_integral(ir, "cell", prefix)
     code["create_exterior_facet_integral"] = _create_foo_integral(ir, "exterior_facet", prefix)
     code["create_interior_facet_integral"] = _create_foo_integral(ir, "interior_facet", prefix)
@@ -417,12 +428,12 @@ def _tabulate_entity_dofs(ir):
 
 def _create_foo(prefix, class_name, postfix, numbers=None):
     "Generate code for create_<foo>."
-    f_i =     format["argument sub"]
-    ret =     format["return"]
-    create =  format["create foo"]
+    f_i    = format["argument sub"]
+    ret    = format["return"]
+    create = format["create foo"]
 
     class_names = ["%s_%s_%d" % (prefix.lower(), class_name, i) for i in postfix]
-    cases = [ret(create(name + "()")) for name in class_names]
+    cases = [ret(create(name)) for name in class_names]
     default = ret(0)
     return format["switch"](f_i, cases, default=default, numbers=numbers)
 
