@@ -7,7 +7,7 @@ __license__  = "GNU GPL version 3 or any later version"
 
 # Modified by Kristian B. Oelgaard 2010
 # Modified by Marie E. Rognes 2010
-# Last changed: 2010-03-11
+# Last changed: 2011-02-21
 
 # Python modules
 import re, numpy, platform
@@ -36,6 +36,11 @@ format.update({
     "loop":           lambda i, j, k: "for (unsigned int %s = %s; %s < %s; %s++)"% (i, j, i, k, i),
     "generate loop":  lambda v, w, _indent=0: _generate_loop(v, w, _indent),
     "is equal":       " == ",
+    "not equal":      " == ",
+    "less than":      " < ",
+    "greater than":   " > ",
+    "less equal":     " <= ",
+    "greater equal":  " >= ",
     "do nothing":     "// Do nothing"
 })
 
@@ -51,7 +56,7 @@ format.update({
     "const uint declaration":         lambda v, w: "const unsigned int %s = %s;" % (v, w),
     "dynamic array":                  lambda t, n, s: "%s *%s = new %s[%s];" % (t, n, t, s),
     "delete dynamic array":           lambda n, s=None: _delete_array(n, s),
-    "create foo":                     lambda v: "new %s" % v
+    "create foo":                     lambda v: "new %s()" % v
 })
 
 # Mathematical operators
@@ -96,6 +101,8 @@ format.update({
     "J":                lambda i, j: "J_%d%d" % (i, j),
     "inv(J)":           lambda i, j: "K_%d%d" % (i, j),
     "det(J)":           lambda r=None: "detJ%s" % choose_map[r],
+    "cell volume":      lambda r=None: "volume%s" % choose_map[r],
+    "circumradius":     lambda r=None: "circumradius%s" % choose_map[r],
     "scale factor":     "det",
     "transform":        lambda t, j, k, r: _transform(t, j, k, r),
     "normal component": lambda r, j: "n%s%s" % (choose_map[r], j),
@@ -171,6 +178,8 @@ format.update({
     "geometry constant":  lambda i: "G[%d]" % i,
     "ip constant":        lambda i: "I[%d]" % i,
     "basis constant":     lambda i: "B[%d]" % i,
+    "conditional":        lambda i: "C[%d]" % i,
+    "evaluate conditional":lambda i,j,k: "(%s) ? %s : %s" % (i,j,k),
 #    "geometry constant":  lambda i: "G%d" % i,
 #    "ip constant":        lambda i: "I%d" % i,
 #    "basis constant":     lambda i: "B%d" % i,
@@ -205,6 +214,8 @@ format.update({
     "facet determinant":    lambda n, r=None: facet_determinant[n] % {"restriction": choose_map[r]},
     "fiat coordinate map":  lambda n: fiat_coordinate_map[n],
     "generate normal":      lambda d, i: _generate_normal(d, i),
+    "generate cell volume": lambda d, i: _generate_cell_volume(d, i),
+    "generate circumradius": lambda d, i: _generate_circumradius(d, i),
     "generate ip coordinates":  lambda g, num_ip, name, ip, r=None: (ip_coordinates[g][0], ip_coordinates[g][1] % \
                                 {"restriction": choose_map[r], "ip": ip, "name": name, "num_ip": num_ip}),
     "scale factor snippet": scale_factor,
@@ -224,7 +235,7 @@ format.update({
     "classname finite_element": lambda prefix, i:\
                "%s_finite_element_%d" % (prefix.lower(), i),
 
-    "classname dof_map":  lambda prefix, i: "%s_dof_map_%d" % (prefix.lower(), i),
+    "classname dofmap":  lambda prefix, i: "%s_dofmap_%d" % (prefix.lower(), i),
 
     "classname cell_integral":  lambda prefix, form_id, sub_domain:\
                "%s_cell_integral_%d_%d" % (prefix.lower(), form_id, sub_domain),
@@ -541,6 +552,38 @@ def _generate_normal(geometric_dimension, domain_type, reference_normal=False):
         error("Unsupported domain_type: %s" % str(domain_type))
     return code
 
+def _generate_cell_volume(geometric_dimension, domain_type):
+    "Generate code for computing cell volume."
+
+    # Choose snippets
+    volume = cell_volume[geometric_dimension]
+
+    # Choose restrictions
+    if domain_type in ("cell", "exterior_facet"):
+        code = volume % {"restriction": ""}
+    elif domain_type == "interior_facet":
+        code = volume % {"restriction": choose_map["+"]}
+        code += volume % {"restriction": choose_map["-"]}
+    else:
+        error("Unsupported domain_type: %s" % str(domain_type))
+    return code
+
+def _generate_circumradius(geometric_dimension, domain_type):
+    "Generate code for computing a cell's circumradius."
+
+    # Choose snippets
+    radius = circumradius[geometric_dimension]
+
+    # Choose restrictions
+    if domain_type in ("cell", "exterior_facet"):
+        code = radius % {"restriction": ""}
+    elif domain_type == "interior_facet":
+        code = radius % {"restriction": choose_map["+"]}
+        code += radius % {"restriction": choose_map["-"]}
+    else:
+        error("Unsupported domain_type: %s" % str(domain_type))
+    return code
+
 # Functions.
 def indent(block, num_spaces):
     "Indent each row of the given string block with n spaces."
@@ -596,7 +639,9 @@ types = [["double"],
          ["const", "int"],
          ["unsigned", "int"],
          ["bool"],
-         ["const", "bool"]]
+         ["const", "bool"],
+         ["static", "unsigned", "int"],
+         ["const", "unsigned", "int"]]
 
 # Special characters and delimiters
 special_characters = ["+", "-", "*", "/", "=", ".", " ", ";", "(", ")", "\\", "{", "}", "[","]"]
@@ -620,8 +665,13 @@ def remove_unused(code, used_set=set()):
 
     lines = code.split("\n")
     for (line_number, line) in enumerate(lines):
+        # Exclude commented lines.
+        if line[:2] == "//" or line[:3] == "///":
+            continue
+
         # Split words
         words = [word for word in line.split(" ") if not word == ""]
+
         # Remember line where variable is declared
         for type in [type for type in types if " ".join(type) in " ".join(words)]: # Fewer matches than line below.
         # for type in [type for type in types if len(words) > len(type)]:
