@@ -187,7 +187,62 @@ class QuadratureTransformerOpt(QuadratureTransformerBase):
         return {():new_val}
 
     # -------------------------------------------------------------------------
-    # FacetNormal (geometry.py).
+    # Condition, Conditional (conditional.py).
+    # -------------------------------------------------------------------------
+    def condition(self, o, *operands):
+
+        # Get LHS and RHS expressions and do safety checks.
+        # Might be a bit too strict?
+        lhs, rhs = operands
+        ffc_assert(len(lhs) == 1 and lhs.keys()[0] == (),\
+            "LHS of Condtion should only be one function: " + repr(lhs))
+        ffc_assert(len(rhs) == 1 and rhs.keys()[0] == (),\
+            "RHS of Condtion should only be one function: " + repr(rhs))
+
+        # Map names from UFL to cpp.py.
+        name_map = {"==":"is equal", "!=":"not equal",\
+                    "<":"less than", ">":"greater than",\
+                    "<=":"less equal", ">=":"greater equal"}
+
+        # Get the minimum type
+        t = min(lhs[()].t, rhs[()].t)
+        sym = create_symbol("", t, cond=(lhs[()], format[name_map[o._name]], rhs[()]))
+        return {(): sym}
+
+    def conditional(self, o, *operands):
+
+        # Get condition and return values; and do safety check.
+        cond, true, false = operands
+        ffc_assert(len(cond) == 1 and cond.keys()[0] == (),\
+            "Condtion should only be one function: " + repr(cond))
+        ffc_assert(len(true) == 1 and true.keys()[0] == (),\
+            "True value of Condtional should only be one function: " + repr(true))
+        ffc_assert(len(false) == 1 and false.keys()[0] == (),\
+            "False value of Condtional should only be one function: " + repr(false))
+
+        # Get values and test for None
+        t_val = true[()]
+        f_val = false[()]
+
+        # Get the minimum type and number of operations.
+        t = min([cond[()].t, t_val.t, f_val.t])
+        ops = sum([cond[()].ops(), t_val.ops(), f_val.ops()])
+
+        # Create expression for conditional
+        # TODO: Handle this differently to expose the variables which are used
+        # to create the expressions.
+        expr = create_symbol(format["evaluate conditional"](cond[()], t_val, f_val), t)
+        num = len(self.conditionals)
+        name = create_symbol(format["conditional"](num), t)
+        if not expr in self.conditionals:
+            self.conditionals[expr] = (t, ops, num)
+        else:
+            num = self.conditionals[expr][2]
+            name = create_symbol(format["conditional"](num), t)
+        return {():name}
+
+    # -------------------------------------------------------------------------
+    # FacetNormal, CellVolume (geometry.py).
     # -------------------------------------------------------------------------
     def facet_normal(self, o,  *operands):
         #print("Visiting FacetNormal:")
@@ -216,6 +271,30 @@ class QuadratureTransformerOpt(QuadratureTransformerBase):
 
         return {(): create_symbol(normal_component, GEO)}
 
+    def cell_volume(self, o,  *operands):
+        # Safety check.
+        ffc_assert(not operands, "Didn't expect any operands for FacetNormal: " + repr(operands))
+
+        # FIXME: KBO: This has to change for higher order elements
+#        detJ = format["det(J)"](self.restriction)
+#        volume = format["absolute value"](detJ)
+#        self.trans_set.add(detJ)
+
+        volume = format["cell volume"](self.restriction)
+        self.trans_set.add(volume)
+
+        return {():create_symbol(volume, GEO)}
+
+    def circumradius(self, o,  *operands):
+        # Safety check.
+        ffc_assert(not operands, "Didn't expect any operands for Circumradius: " + repr(operands))
+
+        # FIXME: KBO: This has to change for higher order elements
+        circumradius = format["circumradius"](self.restriction)
+        self.trans_set.add(circumradius)
+
+        return {():create_symbol(circumradius, GEO)}
+
     def create_argument(self, ufl_argument, derivatives, component, local_comp,
                   local_offset, ffc_element, transformation, multiindices):
         "Create code for basis functions, and update relevant tables of used basis."
