@@ -6,7 +6,7 @@ __copyright__ = "Copyright (C) 2009-2010 Kristian B. Oelgaard"
 __license__  = "GNU GPL version 3 or any later version"
 
 # Modified by Mehdi Nikbakht, 2010
-# Last changed: 2010-06-15
+# Last changed: 2011-02-21
 
 # Python modules.
 import numpy
@@ -21,6 +21,10 @@ from ffc.cpp import format, remove_unused
 # Utility and optimisation functions for quadraturegenerator.
 from symbolics import generate_aux_constants
 
+# Error issued for quadrature version of tabulate_tensor
+tabulate_tensor_quadrature_error = """\
+Quadrature version of tabulate_tensor not yet implemented (introduced in UFC 2.0)."""
+
 def generate_integral_code(ir, prefix, parameters):
     "Generate code for integral from intermediate representation."
 
@@ -33,6 +37,7 @@ def generate_integral_code(ir, prefix, parameters):
     code["initializer_list"] = ""
     code["destructor"] = format["do nothing"]
     code["tabulate_tensor"] = _tabulate_tensor(ir, parameters)
+    code["tabulate_tensor_quadrature"] = format["exception"](tabulate_tensor_quadrature_error)
 
     return code
 
@@ -137,6 +142,10 @@ def _tabulate_tensor(ir, parameters):
     else:
         error("Unhandled integral type: " + str(integral_type))
 
+    # Add common (for cell, exterior and interior) geo code.
+    jacobi_code += "\n\n" + format["generate cell volume"](geo_dim, domain_type)
+    jacobi_code += "\n\n" + format["generate circumradius"](geo_dim, domain_type)
+
     # After we have generated the element code for all facets we can remove
     # the unused transformations and tabulate the used psi tables and weights.
     common = [remove_unused(jacobi_code, trans_set)]
@@ -190,6 +199,7 @@ def _generate_element_tensor(integrals, sets, optimise_parameters):
     f_double  = format["float declaration"]
     f_decl    = format["declaration"]
     f_X       = format["ip coordinates"]
+    f_C       = format["conditional"]
 
 
     # Initialise return values.
@@ -204,7 +214,7 @@ def _generate_element_tensor(integrals, sets, optimise_parameters):
     members_code = ""
     # We receive a dictionary {num_points: form,}.
     # Loop points and forms.
-    for points, terms, functions, ip_consts, coordinate in integrals:
+    for points, terms, functions, ip_consts, coordinate, conditionals in integrals:
 
         element_code += ["", f_comment("Loop quadrature points for integral.")]
 
@@ -229,6 +239,21 @@ def _generate_element_tensor(integrals, sets, optimise_parameters):
             ip_code += func_code
             num_ops += ops
 
+        # Generate code to compute conditionals (might depend on coordinates
+        # and function values so put here).
+        # TODO: Some conditionals might only depend on geometry so they
+        # should be moved outside if possible.
+        if conditionals:
+            ip_code += [f_decl(f_double, f_C(len(conditionals)))]
+            # Sort conditionals (need to in case of nested conditionals).
+            reversed_conds = dict([(n, (o, e)) for e, (t, o, n) in conditionals.items()])
+            for num in range(len(conditionals)):
+                name = format["conditional"](num)
+                ops, expr = reversed_conds[num]
+                ip_code += [f_comment("Compute conditional, operations: %d." % ops)]
+                ip_code += [format["assign"](name, expr)]
+                num_ops += ops
+
         # Generate code for ip constant declarations.
 #        ip_const_ops, ip_const_code = generate_aux_constants(ip_consts, f_I,\
 #                                        format["const float declaration"], True)
