@@ -3,7 +3,7 @@ __date__ = "2010-02-08"
 __copyright__ = "Copyright (C) 2010 Kristian B. Oelgaard"
 __license__  = "GNU GPL version 3 or any later version"
 
-# Last changed: 2010-05-04
+# Last changed: 2011-01-11
 
 # FFC modules
 from ffc.log import info
@@ -11,9 +11,12 @@ from ffc.cpp import format
 from ffc.quadrature.symbolics import optimise_code, BASIS, IP, GEO, CONST
 from ffc.quadrature.symbolics import create_product, create_sum, create_symbol, create_fraction
 
-def optimize_integral_ir(ir):
+def optimize_integral_ir(ir, parameters):
     "Compute optimized intermediate representation of integral."
 
+    # FIXME: input argument "parameters" has been added to optimize_integral_ir
+    # FIXME: which shadows a local parameter
+
     parameters = ir["optimise_parameters"]
     if parameters["optimisation"]:
         integrals  =  ir["trans_integrals"]
@@ -48,7 +51,7 @@ def optimize_integral_ir(ir):
     return ir
 
 def _simplify_expression(integral, geo_consts, psi_tables_map):
-    for points, terms, functions, ip_consts, coordinate in integral:
+    for points, terms, functions, ip_consts, coordinate, conditionals in integral:
         for loop, (data, entry_vals) in terms.iteritems():
             t_set, u_weights, u_psi_tables, u_nzcs, basis_consts = data
             new_entry_vals = []
@@ -64,7 +67,7 @@ def _simplify_expression(integral, geo_consts, psi_tables_map):
             terms[loop][1] = new_entry_vals
 
 def _precompute_expressions(integral, geo_consts, optimisation):
-    for points, terms, functions, ip_consts, coordinate in integral:
+    for points, terms, functions, ip_consts, coordinate, conditionals in integral:
         for loop, (data, entry_vals) in terms.iteritems():
             t_set, u_weights, u_psi_tables, u_nzcs, basis_consts = data
             new_entry_vals = []
