@@ -33,6 +33,7 @@ from ffc.cpp import format
 from quadraturetransformerbase import QuadratureTransformerBase
 from quadratureutils import create_permutations
 from reduce_operations import operation_count
+from symbolics import IP
 
 class QuadratureTransformer(QuadratureTransformerBase):
     "Transform UFL representation to quadrature code."
@@ -262,7 +263,65 @@ class QuadratureTransformer(QuadratureTransformerBase):
         return {():f_abs(operands[0][()])}
 
     # -------------------------------------------------------------------------
-    # FacetNormal (geometry.py).
+    # Condition, Conditional (conditional.py).
+    # -------------------------------------------------------------------------
+    def condition(self, o, *operands):
+
+        # Get LHS and RHS expressions and do safety checks.
+        # Might be a bit too strict?
+        lhs, rhs = operands
+        ffc_assert(len(lhs) == 1 and lhs.keys()[0] == (),\
+            "LHS of Condtion should only be one function: " + repr(lhs))
+        ffc_assert(len(rhs) == 1 and rhs.keys()[0] == (),\
+            "RHS of Condtion should only be one function: " + repr(rhs))
+
+        # Map names from UFL to cpp.py.
+        name_map = {"==":"is equal", "!=":"not equal",\
+                    "<":"less than", ">":"greater than",\
+                    "<=":"less equal", ">=":"greater equal"}
+
+        # Get values and test for None
+        l_val = lhs[()]
+        r_val = rhs[()]
+        if l_val is None:
+            l_val = format["float"](0.0)
+        if r_val is None:
+            r_val = format["float"](0.0)
+
+        return {(): l_val + format[name_map[o._name]] + r_val}
+
+    def conditional(self, o, *operands):
+
+        # Get condition and return values; and do safety check.
+        cond, true, false = operands
+        ffc_assert(len(cond) == 1 and cond.keys()[0] == (),\
+            "Condtion should only be one function: " + repr(cond))
+        ffc_assert(len(true) == 1 and true.keys()[0] == (),\
+            "True value of Condtional should only be one function: " + repr(true))
+        ffc_assert(len(false) == 1 and false.keys()[0] == (),\
+            "False value of Condtional should only be one function: " + repr(false))
+
+        # Get values and test for None
+        t_val = true[()]
+        f_val = false[()]
+        if t_val is None:
+            t_val = format["float"](0.0)
+        if f_val is None:
+            f_val = format["float"](0.0)
+
+        # Create expression for conditional
+        expr = format["evaluate conditional"](cond[()], t_val, f_val)
+        num = len(self.conditionals)
+        name = format["conditional"](num)
+        if not expr in self.conditionals:
+            self.conditionals[expr] = (IP, operation_count(expr, format), num)
+        else:
+            num = self.conditionals[expr][2]
+            name = format["conditional"](num)
+        return {():name}
+
+    # -------------------------------------------------------------------------
+    # FacetNormal, CellVolume (geometry.py).
     # -------------------------------------------------------------------------
     def facet_normal(self, o,  *operands):
         #print("Visiting FacetNormal:")
@@ -291,6 +350,27 @@ class QuadratureTransformer(QuadratureTransformerBase):
 
         return {():normal_component}
 
+    def cell_volume(self, o,  *operands):
+        # Safety check.
+        ffc_assert(not operands, "Didn't expect any operands for CellVolume: " + repr(operands))
+
+        # FIXME: KBO: This has to change for higher order elements
+        volume = format["cell volume"](self.restriction)
+        self.trans_set.add(volume)
+
+        return {():volume}
+
+    def circumradius(self, o,  *operands):
+        # Safety check.
+        ffc_assert(not operands, "Didn't expect any operands for Circumradius: " + repr(operands))
+
+        # FIXME: KBO: This has to change for higher order elements
+        circumradius = format["circumradius"](self.restriction)
+        self.trans_set.add(circumradius)
+
+        return {():circumradius}
+
+
     def create_argument(self, ufl_argument, derivatives, component, local_comp,
                   local_offset, ffc_element, transformation, multiindices):
         "Create code for basis functions, and update relevant tables of used basis."
