@@ -87,6 +87,8 @@ def _compute_element_ir(ufl_element, element_id, element_map):
     # Compute data for each function
     ir["signature"] = repr(ufl_element)
     ir["cell_shape"] = cell.domain()
+    ir["topological_dimension"] = cell.topological_dimension()
+    ir["geometric_dimension"] = cell.geometric_dimension()
     ir["space_dimension"] = element.space_dimension()
     ir["value_rank"] = len(ufl_element.value_shape())
     ir["value_dimension"] = ufl_element.value_shape()
@@ -120,18 +122,19 @@ def _compute_dofmap_ir(ufl_element, element_id, element_map):
     ir["init_mesh"] = _init_mesh(element)
     ir["init_cell"] = None
     ir["init_cell_finalize"] = None
+    ir["topological_dimension"] = cell.topological_dimension()
+    ir["geometric_dimension"] = cell.geometric_dimension()
     ir["global_dimension"] = None
     ir["local_dimension"] = element.space_dimension()
     ir["max_local_dimension"] = element.space_dimension()
-    ir["geometric_dimension"] = cell.geometric_dimension()
     ir["num_facet_dofs"] = len(facet_dofs[0])
     ir["num_entity_dofs"] = num_dofs_per_entity
     ir["tabulate_dofs"] = _tabulate_dofs(element, cell)
     ir["tabulate_facet_dofs"] = facet_dofs
     ir["tabulate_entity_dofs"] = (element.entity_dofs(), num_dofs_per_entity)
     ir["tabulate_coordinates"] = _tabulate_coordinates(element)
-    ir["num_sub_dof_maps"] = ufl_element.num_sub_elements()
-    ir["create_sub_dof_map"] = _create_sub_foo(ufl_element, element_map)
+    ir["num_sub_dofmaps"] = ufl_element.num_sub_elements()
+    ir["create_sub_dofmap"] = _create_sub_foo(ufl_element, element_map)
 
     #debug_ir(ir, "dofmap")
 
@@ -204,11 +207,11 @@ def _compute_form_ir(form, form_id, element_map):
     ir["signature"] = repr(form)
     ir["rank"] = form_data.rank
     ir["num_coefficients"] = form_data.num_coefficients
-    ir["num_cell_integrals"] = form_data.num_cell_domains
-    ir["num_exterior_facet_integrals"] = form_data.num_exterior_facet_domains
-    ir["num_interior_facet_integrals"] = form_data.num_interior_facet_domains
+    ir["num_cell_domains"] = form_data.num_cell_domains
+    ir["num_exterior_facet_domains"] = form_data.num_exterior_facet_domains
+    ir["num_interior_facet_domains"] = form_data.num_interior_facet_domains
     ir["create_finite_element"] = [element_map[e] for e in form_data.elements]
-    ir["create_dof_map"] = [element_map[e] for e in form_data.elements]
+    ir["create_dofmap"] = [element_map[e] for e in form_data.elements]
     ir["create_cell_integral"] = _create_foo_integral("cell", form_data)
     ir["create_exterior_facet_integral"] = _create_foo_integral("exterior_facet", form_data)
     ir["create_interior_facet_integral"] = _create_foo_integral("interior_facet", form_data)
